
/* MX LIBRARY FUNCTION:  mxip_image_s_list_f5
 *
 * PURPOSE:  List the pixel values of a mxip_image_s structure.
 *
 * AUTHOR:  K. J. Mighell (mighell@noao.edu)
 *
 * LANGUAGE:  ANSI C
 *
 * DOCUMENTATION:  http://www.noao.edu/staff/mighell/mx
 *
 * DATE:  20000313
 *
 * MOD:  3
 * 
 * Copyleft (L) 2000 Kenneth John Mighell
 */

#include "mx.h"

int mxip_image_s_list_f5( 
  struct mxip_image_s *image,
  int ix0b,
  int ix0e_,
  int iy0b,
  int iy0e_
) {

  char mxfunc[] =  "mxip_image_s_list_f5";
  int status;

  int ix0e = ix0e_;
  int iy0e = iy0e_;
  int nx;
  int ny;
  int idx0;
  int idy0;
  int ix0;
  int iy0;
  int xmn;
  int xmx;
  int ymn;
  int ymx;
  int long_form;

  if ( mxip_image_s_ok_f1 (image) ) {
    status = 1;
    goto error;
  }

  nx = (image->nxi);
  ny = (image->nyi);
  idx0 = (image->llx0i);
  idy0 = (image->lly0i);
  xmn = 0;
  xmx = nx - 1;
  ymn = 0;
  ymx = ny - 1;
  if (ix0e==-1) ix0e = xmx;
  if (iy0e==-1) iy0e = ymx;

  if ( mxip_image_s_limits_check_f5 (image, ix0b, ix0e, iy0b, iy0e) ) {
    status = 2;
    goto error;
  }

  long_form = (0!=idx0) || (0!=idy0);
  printf ("# %s: =========================================\n", mxfunc);
  printf ("# image->comment is \"%s\"\n", image->comment);
  for (iy0 = iy0b; iy0 <= iy0e; ++iy0) {
    for (ix0 = ix0b; ix0 <= ix0e; ++ix0) {
      printf ("#   image->matrixd[%d][%d] = %12.6e",
        iy0,
        ix0,
        (image->matrixd[iy0][ix0])
      );
      if (long_form) {
        printf ("  <-- [%d][%d]\n",
          (iy0+idy0),
          (ix0+idx0)
        );
      } else {
        printf ("\n");
      }
    }
  }
  printf ("# %s: =========================================\n", mxfunc);

ok:
  status = 0;
  goto bye;

error:
  mxp_errmsg_append_f3 (mxfunc, status, "");
  goto bye;

bye:
  return (status);

}
/* end-of-file */


