
/* MX LIBRARY FUNCTION:  mxiraf_image_s_list_f5
 *
 * PURPOSE:  List the pixel values of a mxiraf_image_s structure. 
 *
 * AUTHOR:  K. J. Mighell (mighell@noao.edu)
 *
 * LANGUAGE:  ANSI C
 *
 * DOCUMENTATION:  http://www.noao.edu/staff/mighell/mx
 *
 * DATE:  20000313
 *
 * MOD:  3
 * 
 * Copyleft (L) 2000 Kenneth John Mighell
 */

#include "mx.h"

int mxiraf_image_s_list_f5( 
  struct mxiraf_image_s *image,
  int ix0b,
  int ix0e_,
  int iy0b,
  int iy0e_
) {

  char mxfunc[] = "mxiraf_image_s_list_f5";
  int status;

  int ix0e = ix0e_;
  int iy0e = iy0e_;
  int nx;
  int ny;
  int ix0;
  int iy0;
  int xmn;
  int xmx;
  int ymn;
  int ymx;
  int idx1;
  int idy1;
  int ix1;
  int iy1;
  int row_offset;
  int pxi; 

  if ( mxiraf_image_s_ok_f1 (image) ) {
    status = 1;
    goto error;
  }

  nx = image->data->nxi;
  ny = image->data->nyi;
  xmn = 0;
  xmx = nx - 1;
  ymn = 0;
  ymx = ny - 1;
  idx1 = image->data->llx0i + 1;
  idy1 = image->data->lly0i + 1;

  if (ix0e==-1) ix0e = xmx;
  if (iy0e==-1) iy0e = ymx;

  if ( mxiraf_image_s_limits_check_f5 (image, ix0b, ix0e, iy0b, iy0e) ) {
    status = 2;
    goto error;
  }

  for (iy0 = iy0b; iy0 <= iy0e; ++iy0) {
    iy1 = iy0 + 1;
    row_offset = iy0*nx;
    for (ix0 = ix0b; ix0 <= ix0e; ++ix0) {
      ix1 = ix0 + 1;
      pxi = row_offset + ix0;
      printf (
"%s%6d%6d%12.6e%6d%6d%9d\n",
"# ",(ix0+idx1), (iy0+idy1), (image->data->vectord[pxi]), ix1, iy1, pxi
      );
    }
  }
  printf ("#--> X_P   Y_P     value     X_L   Y_L   offset\n");
  printf ("#   (physical)               (logical) <-- coordinate system\n");

ok:
  status = 0;
  goto bye;

error:
  mxp_errmsg_append_f3 (mxfunc, status, "");
  goto bye;

bye:
  return (status);

}
#undef MXFNAME 
/* end-of-file */

