     
/*      FILE: /mxtools/src/mximg2d/inc.h
 *   PURPOSE: MXIMG2D routines *must* include this file!
 *    AUTHOR: K. J. Mighell (mighell@noao.edu)
 *  LANGUAGE: ANSI C
 *      DATE: 2001OCT25
 * COPYRIGHT: (C) 2001 Assoc. of Universities for Research in Astronomy Inc.
 */

#ifndef MXIMG2D_H

# define MXIMG2D_H         "MXIMG2D"
# define MXIMG2D_AUTHOR    "Kenneth J. Mighell"
# define MXIMG2D_EMAIL     "mighell@noao.edu"
# define MXIMG2D_COPYRIGHT "Copyright (C) 2001 Association of Universities for Research in Astronomy Inc."
# define MXIMG2D_VERSION   "2001OCT31X"
# define MXIMG2D_DATE      "20011031"

typedef struct {
  struct mxiraf_image_s *mxIrafImage;
  char ifn[MX_IRAF_SZ_FNAME+1];
  double **matrixd;
  double *vectord;
  int llx0i;
  int lly0i;
  int nxi;
  int nyi;
  int xdimi;
  int ydimi;
  int npxi;
} inc_ImageS;

typedef struct {
  char image[MX_IRAF_SZ_FNAME+1];
  double volume;
  double sigma;
  double x;
  double y;
  char MXIMG2D[8+1];
  char PROGFILE[MX_IRAF_SZ_FNAME+1];
  char PROGDATE[11+1];
  char PROGTIME[8+1];
} inc_ParS;

extern
int inc_ParS_Get_i1 (
  inc_ParS *ParS
)
;

extern
int inc_ParS_Put_i1 (
  inc_ParS *ParS
)
;

extern
void inc_ParS_Print_v2 (
  inc_ParS *ParS,
  FILE *ofp
)
;

extern
void inc_Banner_v2 (
  FILE *ofp,
  char *tag
)
;

extern 
int inc_IrafParDoubleGet_v4 (
 char text[],
 double defaultd,
 double *valued_p,
 int *is_INDEF_p
)
;

extern 
int inc_IrafParStringGet_v5 (
 char text[],
 char default_value[],
 char value[],
 int maxch,
 int *is_INDEF_p
)
;

extern 
int inc_ImageS_Open_i2 (
  inc_ParS *ParS,
  inc_ImageS *ImageS
)
;

extern 
int inc_ImageS_Close_i1 (
  inc_ImageS *ImageS
)
;

extern
void VecdRobustMdn_v6 (
  double *pxv,
  int px_n,
  double *tv,
  int *median_n_,
  double *median_,
  double *adev_
)
;

extern
int inc_ImageS_Add_Gaussian2d_i2(
  inc_ParS *ParS,
  inc_ImageS *ImageS
)
;

extern
void Gaussian2d_v8( 
  double ig,      /*                volume of 2-d Gaussian */
  double xgp,     /* X physical coordinate of 2-d Gaussian */
  double ygp,     /* Y physical coordinate of 2-d Gaussian */
  double sg,      /*                 sigma of 2-d Gaussian */
  int    res_p,   /* resolution = sqrt(total number of subpixels) */
  double xp,      /* X physical coordinate of pixel */
  double yp,      /* Y physical coordinate of pixel */
  double *z_p     /* value of 2-d Gaussian at Z = Gaussian2d(X,Y) */
)
;

#endif
/* end-of-file */










