#
procedure psfg2d (out_, nx_, ny_, cpxi_, cpyi_, fwhm_)
string out_="" {prompt="Name of output PSF image?"}
int nx_=101 {prompt="Number of columns for PSF?"}
int ny_=101 {prompt="Number of    rows for PSF?"}
real cpxi_=50.0 {prompt="X position of the center of 2-d Gaussian (IRAF notation) ?"}
real cpyi_=50.0 {prompt="Y position of the center of 2-d Gaussian (IRAF notation) ?"}
real fwhm_=5.0 {prompt="Full-Width-at-Half-Maximum of 2-d Gaussian ?"}
int mpxi=1 {prompt="OverSamplingFactor (1 -> 1x1, 2 -> 2x2) ?"}
bool verbose=no {prompt="Verbose?"}
string version="2001OCT31" {prompt="PSFG2D version"}

begin

real psf_cwxi
real psf_cwyi
real psf_cpxi
real psf_cpyi
int psf_nx
int psf_ny
real mag
string coo
string work
string comment
string out
int nx
int ny
real cpxi
real cpyi
real fwhm
real hwhm
real sigma

version="2001OCT31"

if (verbose) print  ( "PSFG2D: BEGIN" )

# Make sure correct packages are loaded
if (!defpac("noao")) {
  print "Please load the NOAO package"; 
  goto bye
}
if (!defpac("ctio")) {
  print "Please load the CTIO package"; 
  goto bye
}

out = out_
if (access(out)) {
  print ( "PSFPREP *** ERROR *** :Output file already exisits!" )
  goto bye;
}

nx = nx_
ny = ny_
cpxi = cpxi_
cpyi = cpyi_
fwhm = fwhm_
hwhm = fwhm/2.0
mag = 0
sigma = fwhm/2.354
work = ".psfg2d.fits"

delete( work, verify-, >& "dev$null" )

#if (!defpac("artdata")) {
#  print "Please load the ARTDATA package of the NOAO package"; 
#  goto bye
#}
#coo = ".psfg2d.coo"
#delete( coo, verify-, >& "dev$null" )
#print( cpxi, cpyi, mag, > coo )
#unlearn artdata
#unlearn mkobj
#artdata.nxc=10
#artdata.nyc=10
#artdata.nxsub=10
#artdata.nysub=10
#artdata.dynrange=10000000000.
#artdata.ranbuf=0
#mkobj( input=work, ncols=nx, nlines=ny, background=0., objects=coo,
#  gain=1.0, rdnoise=0.0, poisson=no,
#  header="", star="gaussian", radius=hwhm, magzero=0., comments=no)

ctio.imcreate (image=work, naxis=2, naxis1=nx*mpxi, naxis2=ny*mpxi, pixtype="real")
mximg2d (image=work, volume=1.0, sigma=sigma*mpxi, x=cpxi, y=cpyi, >& "dev$null" )

hedit ( work, "psfg2d", value=version, add=yes, verify=no, update=yes, 
  > "dev$null")
hedit ( work, "g2d_cpxi", value=cpxi, add=yes, verify=no, update=yes, 
  > "dev$null")
hedit ( work, "g2d_cpyi", value=cpyi, add=yes, verify=no, update=yes, 
  > "dev$null")
hedit ( work, "g2d_fwhm", value=fwhm, add=yes, verify=no, update=yes, 
  > "dev$null")
hedit ( work, "g2d_mag", value=mag, add=yes, verify=no, update=yes, 
  > "dev$null")

unlearn psfprep
psfprep( work, out, psf_cpxi=cpxi, psf_cpyi=cpyi, psf_mpxi=mpxi, norm=1,>& "dev$null" )

bye:
if (verbose) print  ( "PSFG2D: END" )
end
