
/*      FILE:  /mxtools/src/psfshift/psf_close.c
 *   PURPOSE:  Close a PSFSHIFT PsfS.
 *    AUTHOR:  Kenneth J. Mighell (mighell@noao.edu)
 *  LANGUAGE:  ANSI C
 *      DATE:  2001OCT26
 * COPYRIGHT:  (C) 2001 Assoc. of Universities for Research in Astronomy Inc.
 */

#include <mx.h>
#include "inc.h"

int inc_PsfS_Close_i1 (
  inc_PsfS *PsfS
){

  char mxfunc[] = "inc_PsfS_Close_i1";
  int mxstatus=0;
  int status;
  IRAFPointer ifp;

  ifp = PsfS->mxIrafImage->ptr;

  mxstatus++;
  c_imputd( ifp, "PSF_CPXP", PsfS->PSF_CPXP );
  if ( mxiraf_cvos_error_check_f0() ) goto mx_error;
  printf ("PSF_CPXP is %g\n", PsfS->PSF_CPXP);

  mxstatus++;
  c_imputd( ifp, "PSF_CPYP", PsfS->PSF_CPYP );
  if ( mxiraf_cvos_error_check_f0() ) goto mx_error;
  printf ("PSF_CPYP is %g\n", PsfS->PSF_CPYP);

  PsfS->PSF_CPXJ = PsfS->PSF_CPXP;
  mxstatus++;
  c_imputi( ifp, "PSF_CPXJ", PsfS->PSF_CPXJ );
  if ( mxiraf_cvos_error_check_f0() ) goto mx_error;
  printf ("PSF_CPXJ is %d\n", PsfS->PSF_CPXJ);

  PsfS->PSF_CPYJ = PsfS->PSF_CPYP;
  mxstatus++;
  c_imputi( ifp, "PSF_CPYJ", PsfS->PSF_CPYJ );
  if ( mxiraf_cvos_error_check_f0() ) goto mx_error;
  printf ("PSF_CPYJ is %d\n", PsfS->PSF_CPYJ);

  PsfS->PSF_CPXF = PsfS->PSF_CPXP  - PsfS->PSF_CPXJ;
  mxstatus++;
  c_imputd( ifp, "PSF_CPXF", PsfS->PSF_CPXF );
  if ( mxiraf_cvos_error_check_f0() ) goto mx_error;
  printf ("PSF_CPXF is %g\n", PsfS->PSF_CPXF);

  PsfS->PSF_CPYF = PsfS->PSF_CPYP  - PsfS->PSF_CPYJ;
  mxstatus++;
  c_imputd( ifp, "PSF_CPYF", PsfS->PSF_CPYF );
  if ( mxiraf_cvos_error_check_f0() ) goto mx_error;
  printf ("PSF_CPYF is %g\n", PsfS->PSF_CPYF);

  PsfS->PSF_CPXI = PsfS->PSF_CPXP + 0.5;
  mxstatus++;
  c_imputd( ifp, "PSF_CPXI", PsfS->PSF_CPXI );
  if ( mxiraf_cvos_error_check_f0() ) goto mx_error;
  printf ("PSF_CPXI is %g\n", PsfS->PSF_CPXI);

  PsfS->PSF_CPYI = PsfS->PSF_CPYP + 0.5;
  mxstatus++;
  c_imputd( ifp, "PSF_CPYI", PsfS->PSF_CPYI );
  if ( mxiraf_cvos_error_check_f0() ) goto mx_error;
  printf ("PSF_CPYI is %g\n", PsfS->PSF_CPYI);

  mxstatus++;
  status = mxiraf_image_s_close_f1(&PsfS->mxIrafImage);
  if (status) goto mx_error;

ok:
  status = 0;
  goto bye;

mx_error:
  mxp_errmsg_append_f3 (mxfunc, mxstatus, "");
  goto bye;

mx_error2:
  mxp_errmsg_append_f3 (mxfunc, mxstatus, MX.tmpmsg);
  goto bye;

bye:
  return(status);
  
}
/* end-of-file */
