
/*      FILE:  par_print.c
 *   PURPOSE:  Print a qdphot5_ParS.
 *    AUTHOR:  Kenneth J. Mighell (mighell@noao.edu)
 *  LANGUAGE:  ANSI C
 *      DATE:  2001JUL03
 * COPYRIGHT:  (C) 2001 Assoc. of Universities for Research in Astronomy Inc.
 */

#include "mx.h"
#include "qdphot.h"

void qdphot5_ParS_Print_vf2 (
  qdphot5_ParS *ParS,
  FILE *ofp
){

  char mxfunc[] = "qdphot5_ParS_Print_vf2";
  int status;
  int isNullFile;
  char *tag[] = { "\0", "[<--INDEF]" };

  isNullFile = ((FILE *)NULL == ofp);
  if (isNullFile) goto bye;

  qdphot5_Banner_vf2 (ofp, "#");

  fprintf (ofp, "# qdphot\n");
  fprintf (ofp, "#      image1 = \"%s\"\n", ParS->image[1]);
  fprintf (ofp, "#      image2 = \"%s\" %s\n", 
    ParS->image[2], tag[ParS->image_is_INDEF[2]]);
  fprintf (ofp, "#      coords = \"%s\"\n", ParS->coo);
  fprintf (ofp, "#       (out1 = \"%s\" )%s\n", 
    ParS->out[1], tag[ParS->out_is_INDEF[1]]);
  fprintf (ofp, "#       (out2 = \"%s\" )%s\n", 
    ParS->out[2], tag[ParS->out_is_INDEF[2]]);
  fprintf (ofp, "#      (gain1 = %g )%s\n", 
    ParS->gain[1], tag[ParS->gain_is_INDEF[1]]);
  fprintf (ofp, "#      (gain2 = %g )%s\n", 
    ParS->gain[2], tag[ParS->gain_is_INDEF[2]]);
  fprintf (ofp, "#       (ron1 = %g )%s\n", 
    ParS->ron[1], tag[ParS->ron_is_INDEF[1]]);
  fprintf (ofp, "#       (ron2 = %g )%s\n", 
    ParS->ron[2], tag[ParS->ron_is_INDEF[2]]);
  fprintf (ofp, "#        (dx1 = %g )%s\n",  ParS->dx[1], 
    tag[ParS->dx_is_INDEF[1]]);
  fprintf (ofp, "#        (dy1 = %g )%s\n",  ParS->dy[1], 
    tag[ParS->dy_is_INDEF[1]]);
  fprintf (ofp, "#        (dx2 = %g )%s\n",  ParS->dx[2], 
    tag[ParS->dx_is_INDEF[2]]);
  fprintf (ofp, "#        (dy2 = %g )%s\n",  ParS->dy[2], 
    tag[ParS->dy_is_INDEF[2]]);
  fprintf (ofp, "#      (bias1 = %g )%s\n", 
    ParS->bias[1], tag[ParS->bias_is_INDEF[1]]);
  fprintf (ofp, "#      (bias2 = %g )%s\n", 
    ParS->bias[2], tag[ParS->bias_is_INDEF[2]]);
  fprintf (ofp, "#     (idint1 = %d )%s\n",  ParS->idint[1], 
    tag[ParS->idint_is_INDEF[1]]);
  fprintf (ofp, "#     (idint2 = %d )%s\n",  ParS->idint[2], 
    tag[ParS->idint_is_INDEF[2]]);
  fprintf (ofp, "#    (search2 = %g )%s\n", ParS->search2,
    tag[ParS->search2_is_INDEF]);
  fprintf (ofp, "#      (mnsnr = %g )%s\n", ParS->mnsnr,
    tag[ParS->mnsnr_is_INDEF]);
  fprintf (ofp, "#    (mxstars = %d )%s\n", ParS->mxstars,
    tag[ParS->mxstars_is_INDEF]);
  fprintf (ofp, "#    (mnpeak1 = %g )%s\n", 
    ParS->mnpeak[1], tag[ParS->mnpeak_is_INDEF[1]]);
  fprintf (ofp, "#    (mnpeak2 = %g )%s\n", 
    ParS->mnpeak[2], tag[ParS->mnpeak_is_INDEF[2]]);
  fprintf (ofp, "#    (mxpeak1 = %g )%s\n", 
    ParS->mxpeak[1], tag[ParS->mxpeak_is_INDEF[1]]);
  fprintf (ofp, "#    (mxpeak2 = %g )%s\n", 
    ParS->mxpeak[2], tag[ParS->mxpeak_is_INDEF[2]]);
  fprintf (ofp, "#    (mnround = %g )%s\n", ParS->mnround,
    tag[ParS->mnround_is_INDEF]);
  fprintf (ofp, "#    (mxround = %g )%s\n", ParS->mxround,
    tag[ParS->mxround_is_INDEF]);
  fprintf (ofp, "#    (mnangle = %g )%s\n", ParS->mnangle,
    tag[ParS->mnangle_is_INDEF]);
  fprintf (ofp, "#    (mxangle = %g )%s\n", ParS->mxangle,
    tag[ParS->mxangle_is_INDEF]);
  fprintf (ofp, "#    (mnsharp = %g )%s\n", ParS->mnsharp,
    tag[ParS->mnsharp_is_INDEF]);
  fprintf (ofp, "#    (mxsharp = %g )%s\n", ParS->mxsharp,
    tag[ParS->mxsharp_is_INDEF]);
  fprintf (ofp, "#    (mnkappa = %g )%s\n", ParS->mnkappa,
    tag[ParS->mnkappa_is_INDEF]);
  fprintf (ofp, "#    (mxkappa = %g )%s\n", ParS->mxkappa,
    tag[ParS->mxkappa_is_INDEF]);
  if (ParS->rejects) {
    fprintf (ofp, "#    (rejects = yes )\n");
  } else {
    fprintf (ofp, "#    (rejects = no )\n");
  }
  fprintf (ofp, "#     (ostars = %d )\n", ParS->ostars);
  fprintf (ofp, "#       (odx2 = %g )\n", ParS->odx2);
  fprintf (ofp, "#       (ody2 = %g )\n", ParS->ody2);
  fprintf (ofp, "#    (ocpusec = %9.2f )\n", ParS->ocpusec);
  fprintf (ofp, "#     (ostart = \"%s\" )\n", ParS->ostart);
  fprintf (ofp, "#      (ostop = \"%s\" )\n", ParS->ostop);

bye:
  return;

}
/* end-of-file */




