
/*      FILE:  phot_print.c
 *   PURPOSE:  Print a qdphot5_PhotS.
 *    AUTHOR:  Kenneth J. Mighell (mighell@noao.edu)
 *  LANGUAGE:  ANSI C
 *      DATE:  2001JUL03
 * COPYRIGHT:  (C) 2001 Assoc. of Universities for Research in Astronomy Inc.
 */

#include "mx.h"
#include "qdphot.h"

void qdphot5_PhotS_Print_vf3 (
  qdphot5_PhotS *PhotS,
  FILE *ofd,
  int option
){
  char mxfunc[] = "qdphot5_PhotS_Print_vf3";
  int status;
  double bkg;

  if ((FILE *)NULL == ofd) goto bye;

  if (option == 1) {

    if ( !(PhotS->ok) ) {
      PhotS->x1outd = PhotS->x1ind;
      PhotS->y1outd = PhotS->y1ind;
      PhotS->id;
      PhotS->ok;
      PhotS->mg  = 44.4444;
      PhotS->emg = 44.4444;
      PhotS->x1cood;
      PhotS->y1cood;
      PhotS->fltrnm;
      PhotS->idint;
      PhotS->round = 0.0000;
      PhotS->angle = 0.0000;
      PhotS->sharp = 0.0000;
      PhotS->kappa = 0.0000;
      PhotS->x1ind;
      PhotS->y1ind;
      PhotS->peakpx = 0.000;
      PhotS->area   = 0.000;
      PhotS->bkg_n  = 0;
      PhotS->bkg    = 0.000;
      PhotS->ebkg   = 0.000;
    }

    if ( (PhotS->ok) || (PhotS->rejects) || (PhotS->moving) ) fprintf (
      ofd,
      "%9.2f%9.2f%6d%10.3f%8.3f%3d%9.2f%9.2f%4d%5d%9.4f%8.2f%9.4f"
      "%8.3f%9.2f%9.2f%13.7e%9.3f%4d%13.7e%13.7e\n",
      PhotS->x1outd,
      PhotS->y1outd,
      PhotS->id,
      PhotS->mg,
      PhotS->emg,
      PhotS->ok,
      PhotS->x1cood,
      PhotS->y1cood,
      PhotS->fltrnm,
      PhotS->idint,
      PhotS->round,
      PhotS->angle,
      PhotS->sharp,
      PhotS->kappa,
      PhotS->x1ind,
      PhotS->y1ind,
      PhotS->peakpx,
      PhotS->area,
      PhotS->bkg_n,
      PhotS->bkg,
      PhotS->ebkg
    );
  } else { /* describe columns */
    fprintf (ofd, "#     (1)");
    fprintf (ofd, "      (2)");
    fprintf (ofd, "   (3)");
    fprintf (ofd, "       (4)");
    fprintf (ofd, "     (5)");
    fprintf (ofd, " (6)");
    fprintf (ofd, "     (7)");
    fprintf (ofd, "      (8)");
    fprintf (ofd, "  (9)");
    fprintf (ofd, " (10)");
    fprintf (ofd, "    (11)");
    fprintf (ofd, "    (12)");
    fprintf (ofd, "     (13)");
    fprintf (ofd, "    (14)");
    fprintf (ofd, "     (15)");
    fprintf (ofd, "     (16)");
    fprintf (ofd, "         (17)");
    fprintf (ofd, "     (18)");
    fprintf (ofd, " (19)");
    fprintf (ofd, "        (20)");
    fprintf (ofd, "         (21)");
    fprintf (ofd, "\n");
    fprintf (ofd, "#\n");
    fprintf (ofd, "# column description\n");
    fprintf (ofd, "#    (1) X coordinate position [px]\n"); 
    fprintf (ofd, "#    (2) Y coordinate position [px]\n"); 
    fprintf (ofd, "#    (3) identifier\n"); 
    fprintf (ofd, "#    (4) stellar magnitude [0 mag -> 1 electrons]\n"); 
    fprintf (ofd, "#    (5) error of stellar magnitude [mag]\n"); 
    fprintf (ofd, "#    (6) status (1 is OK)\n"); 
    fprintf (ofd, "#    (7) Xcoo [px]\n"); 
    fprintf (ofd, "#    (8) Ycoo [px]\n"); 
    fprintf (ofd, "#    (9) image number (1 or 2)\n"); 
    fprintf (ofd, "#   (10) Integer identifier\n"); 
    fprintf (ofd, "#   (11) ROUND (eccentricity: 0 <= ROUND <= 1)\n"); 
    fprintf (ofd, "#   (12) ANGLE (position angle: -90 <= ANGLE <= 90 degrees)\n"); 
    fprintf (ofd, "#   (13) SHARP (sharpness: 0 <= SHARP <= 1)\n"); 
    fprintf (ofd, "#   (14) KAPPA [log10(peak_flux_ratio/3.36)]\n"); 
    fprintf (ofd, "#   (15) Xin [px]\n"); 
    fprintf (ofd, "#   (16) Yin [px]\n"); 
    fprintf (ofd, "#   (17) central pixel value [DN]\n"); 
    fprintf (ofd, "#   (18) area of the stellar aperture [px]\n"); 
    fprintf (ofd, "#   (19) number of pixels used in sky aperture [px]\n"); 
    fprintf (ofd, "#   (20) background [electrons *not* DN]\n"); 
    fprintf (ofd, "#   (21) error of background [electrons *not* DN]\n"); 
  }

bye:
  return;

}
/* end-of-file */

