      
/*      FILE:  qdphot.h
 *   PURPOSE:  QDPHOT5 routines *must* include this file!
 *    AUTHOR:  Kenneth J. Mighell (mighell@noao.edu)
 *  LANGUAGE:  ANSI C
 *      DATE:  2001JUN19
 * COPYRIGHT: (C) 2001 Assoc. of Universities for Research in Astronomy Inc.
 */

#ifndef QDPHOT5_H

# define QDPHOT_H         "QDPHOT5"
# define QDPHOT_AUTHOR    "Kenneth J. Mighell"
# define QDPHOT_EMAIL     "mighell@noao.edu"
# define QDPHOT_URL       "http://www.noao.edu/staff/mighell/?"
# define QDPHOT_COPYRIGHT "Copyright(c) 2001 Association of Universities for Research in Astronomy Inc."
# define QDPHOT_DATE      "2001JUL03"
# define QDPHOT_MOD       0
# define QDPHOT_VERSION   "5"
/*
 * QDPHOT_VERSION   "2001APR19v4"
 */

# define QDPHOT_BIG       1.0e30
# define QDPHOT_HUGE      1.0e38

# define QDPHOT_COODIM    1000000

typedef struct {
  struct mxiraf_image_s *mxIrafImage;
  char ifn[MX_IRAF_SZ_FNAME+1];
  double **matrixd;
  int llx0i;
  int lly0i;
  int nxi;
  int nyi;
  int xdimi;
  int ydimi;
  double dxd;
  double dyd;
  double gain;
  double bias;
  double ron;
  double mnpeak;
  double mxpeak;
  double mnsnr;
  char ofn[MX_IRAF_SZ_FNAME+1];
  FILE *ofp;
  int ofp_is_STDOUT;
  int print;
  int index;
  int idint;
  double matrixd_minimum;
  double matrixd_maximum;
  double mnsharp;
  double mxsharp;
  double mnround;
  double mxround;
  double mnangle;
  double mxangle;
  double mnkappa;
  double mxkappa;
     int rejects;
} qdphot5_ImageS;

typedef struct {
  double xd;
  double yd;
     int idi;
} qdphot5_CooS ;

typedef struct {
     int idint[3];    
     int idint_is_INDEF[3];
     int mxstars;    
     int mxstars_is_INDEF;
  double search2;
     int search2_is_INDEF;
     int dosearch;
     int showsearch;
     int rejects;
     int moving;
  double mnsnr;
     int mnsnr_is_INDEF;
    char image[3][MX_IRAF_SZ_FNAME+1];
     int image_is_INDEF[3];
     int image2_is_image1;
    char out[3][MX_IRAF_SZ_FNAME+1];
     int out_is_INDEF[3];
     int out_is_STDOUT[3];
     int out2_is_out1;
    char coo[MX_IRAF_SZ_FNAME+1];
   FILE *cfp;
     int coo_is_INDEF;
     int coostars;
     int coodim;
qdphot5_CooS *CooS;
   FILE *ofp[3];
  double gain[3];  
     int gain_is_INDEF[3];
  double bias[3];  
     int bias_is_INDEF[3];
  double ron[3];  
     int ron_is_INDEF[3];
  double mnpeak[3];  
     int mnpeak_is_INDEF[3];
  double mxpeak[3];  
     int mxpeak_is_INDEF[3];
  double dx[3];  
     int dx_is_INDEF[3];
  double dy[3];  
     int dy_is_INDEF[3];
     int ostars;
  double odx2;
  double ody2;
  double ocpusec;
    char ostart[MX_IRAF_SZ_FNAME+1];
    char ostop[MX_IRAF_SZ_FNAME+1];
    char odir[MX_IRAF_SZ_FNAME+1];
  double mnsharp;
     int mnsharp_is_INDEF;
  double mxsharp;
     int mxsharp_is_INDEF;
  double mnround;
     int mnround_is_INDEF;
  double mxround;
     int mxround_is_INDEF;
  double mnangle;
     int mnangle_is_INDEF;
  double mxangle;
     int mxangle_is_INDEF;
  double mnkappa;
     int mnkappa_is_INDEF;
  double mxkappa;
     int mxkappa_is_INDEF;
} qdphot5_ParS;

typedef struct {
  int status;
  int ok;
  int moving;
  int rejects;
  double x1cood;
  double y1cood;
  double x1ind;
  double y1ind;
  int x0ini;
  int y0ini;
  double x1outd;
  double y1outd;
  int x0outi;
  int y0outi;
  int x1;
  int y1;
  double xd;
  double yd;
  int id;
  int fltrnm;
  int idint;
  double mg;
  double emg;
  double sgnl;
  double area;
  double bkg;
  double ebkg;
  int bkg_n;
  double cmg;
  double round;   /* eccentricity */
  double angle;  /* position angle */
  double sharp; /* sharpness */
  double fwhm; /* full-width-half-maximum */
  double peakpx;
  double kappa;
} qdphot5_PhotS ;

extern int qdphot5_ImageS_Open_f3 (
  qdphot5_ParS *Par,
  int index,
  qdphot5_ImageS *Image
);

extern int qdphot5_ImageS_Close_f1 (
  qdphot5_ImageS *Image
);

extern int qdphot5_ImageS_MinMax_f1 (
  qdphot5_ImageS *ImageS
);

extern int qdphot5_ParS_CooS_File_f1 (
  qdphot5_ParS *ParS
);

extern int qdphot5_ParS_CooS_Peaker_f3 (
  qdphot5_ParS *ParS,
  qdphot5_ImageS *ImageS,
  int coodim_p
);

extern int qdphot5_ParS_Get_f1 (
  qdphot5_ParS *Par
);

extern int qdphot5_ParS_Put_f1 (
  qdphot5_ParS *Par
);

extern void qdphot5_ParS_Print_vf2 (
  qdphot5_ParS *Par,
  FILE *ofp
);

extern int qdphot5_PhotS_Calc_f5 (
  qdphot5_ImageS *Image,
  qdphot5_PhotS *Phot,
  double x1cood_p,
  double y1cood_p,
  int id_p
);

extern void qdphot5_PhotS_Print_vf3 (
  qdphot5_PhotS *PhotS,
  FILE *ofd,
  int option
);

extern int qdphot5_PhotS_CalcSgnl_f2 (
  qdphot5_ImageS *ImageS,
  qdphot5_PhotS *PhotS
);

extern int qdphot5_PhotS_CalcCheck_f2 (
  qdphot5_ImageS *Image,
  qdphot5_PhotS *Phot
);

extern int qdphot5_PhotS_CalcMag_f2 (
  qdphot5_ImageS *Image,
  qdphot5_PhotS *PhotS
);

extern int qdphot5_PhotS_CalcInit_f5 (
  qdphot5_ImageS *Image,
  qdphot5_PhotS *Phot,
  double x1cood_p,
  double y1cood_p,
  int id_p
);

extern void qdphot5_VecdRobustMdn_vf6 (
  double *pxv,
  int px_n,
  double *tv,
  int *median_n_,
  double *median_,
  double *adev_
);

extern void qdphot5_Banner_vf2 (
  FILE *ofp,
  char *tag
);

extern int qdphot5_IrafParIntegerGet_vf4 (
 char text[],
 int defaulti,
 int *valuei_p,
 int *is_INDEF_p
);

extern int qdphot5_IrafParDoubleGet_vf4 (
 char text[],
 double defaultd,
 double *valued_p,
 int *is_INDEF_p
);

int qdphot5_IrafParStringGet_vf3 (
 char text[],
 char value[],
 int maxch
);

extern int qdphot5_IrafParBooleanGet_vf2 (
 char text[],
 int *valueb_p
);

extern void qdphot5_QDPhot_vf3 (
  qdphot5_ParS *ParS,
  qdphot5_ImageS *ImageS1,
  qdphot5_ImageS *ImageS2
);

extern int qdphot5_Search_f3 (
  qdphot5_ParS *ParS,
  qdphot5_ImageS *ImageS1,
  qdphot5_ImageS *ImageS2
);

#endif
/* end-of-file */








