procedure qdwfpc2(im1,im2)

string im1="mxtools$data/ngc362v3.fits" {prompt="Name of 1st image? "}
string im2="mxtools$data/ngc362b3.fits" {prompt="Name of 2nd image? "}
real search2=0 {prompt="Search radius 2nd image [px] (0.0 <= no search)? "}
real dx2=0 {prompt="DeltaX offset 2nd image [px] ? "}
real dy2=0 {prompt="DeltaY offset 2nd image [px] ? "}
bool show=no {prompt="Show the stars found by QDPHOT?"}
bool print=no {prompt="Print the color-magnitude diagram on stdplot?"}
string section="[60:790,60:790]" {prompt="Image section to analyze on both images?"}
bool unlearn=yes {prompt="Unlearn subordinate tasks (qdphot, wfpc2color, & qdcmd) ? "}
bool nominal=yes {prompt="Is the WFPC2 data nominal? "}

begin
string im1_
string im2_
real search2_
real dx2_
real dy2_
bool show_
bool print_
string out1_
string out2_
string out3_
string section_
string title_
string targname_
int atodgain1_
int atodgain2_
real gain1_
real gain2_
real apcor1_
real apcor2_
int detector1_
int detector2_

if (unlearn) {
  unlearn qdphot
  unlearn qdcmd
  unlearn wfpc2color
}

if (!defpac("stsdas")) {print "Please load the STSDAS package!"; bye}
if (!defpac("graphics")) {print "Please load the GRAPHICS package"; bye}
if (!defpac("graphics")) {print "Please load the STPLOT package!"; bye}
if (!defpac("mxtools")) {print "Please load the MXTOOLS package!"; bye}

im1_=im1
im2_=im2
search2_ = search2
dx2_ = dx2
dy2_ = dy2
show_ = show
print_ = print
section_ = section
im1_=im1_//section_
im2_=im2_//section_
out1_=".qdwfpc2imag1"
out2_=".qdwfpc2imag2"
out3_=".qdwfpc2mag"

delete ( out1_, verify-, >& "dev$null")
delete ( out2_, verify-, >& "dev$null")
delete ( out3_, verify-, >& "dev$null")

hselect ( im1_, "ATODGAIN", yes) | scan( atodgain1_ )
gain1_ = 1.0
if ( atodgain1_ == 7 ) gain1_ = 7.0
if ( atodgain1_ == 15 ) gain1_ = 14.0

hselect ( im2_, "ATODGAIN", yes) | scan( atodgain2_ )
gain2_ = 1.0
if ( atodgain2_ == 7 ) gain2_ = 7.0
if ( atodgain2_ == 15 ) gain2_ = 14.0

qdphot.image1=im1_
qdphot.image2=im2_
qdphot.out1=out1_
qdphot.out2=out2_
qdphot.gain1=gain1_
qdphot.gain2=gain2_
qdphot.ron1=5.2
qdphot.mnpeak1=10.0
qdphot.search2=search2
if (search2!=0.0) {
  dx2_ = 0.0
  dy2_ = 0.0
}
qdphot.dx2 = dx2_
qdphot.dy2 = dy2_
if (nominal) {
  qdphot.mnround=0.0
  qdphot.mxround=0.3
  qdphot.mnkappa=0.0
  qdphot.mxkappa=0.7
  qdphot.mnsharp=0.0
  qdphot.mxsharp=0.3
}
qdphot ( im1_, im2_ )

if (qdphot.ostars<1) goto bye

if (show) {
  display (image=im1_, frame=1, fill+, > "dev$null" )
  unlearn tvmark
  tvmark (1, out1_, color=208, mark="point")
  display (image=im2_, frame=2, fill+, > "dev$null" )
  unlearn tvmark
  tvmark (2, out2_, color=204, mark="point")
}

hselect ( im1_, "DETECTOR", yes) | scan( detector1_ )
if (detector1_ != 0) {
  wfpc2color.apcor1 = -0.1
  if ( detector1_ == 1 ) wfpc2color.apcor1 = -0.2
}
hselect ( im2_, "DETECTOR", yes) | scan( detector2_ )
if (detector2_ != 0) {
  wfpc2color.apcor2 = -0.1
  if ( detector2_ == 1 ) wfpc2color.apcor2 = -0.2
}
wfpc2color.gain1=qdphot.gain1
wfpc2color.gain2=qdphot.gain2
wfpc2color ( out1_, out2_, im1_, im2_, > out3_ )

hselect ( im1_, "TARGNAME", yes) | scan( targname_ )

qdcmd.extra1=wfpc2color.oc7txt//": "//im1_
qdcmd.extra2=wfpc2color.oc8txt//": "//im2_
qdcmd.extra3=qdphot.ostars//" stars"
qdcmd.extra4=""
if ((qdphot.odx2!=0.0)||(qdphot.ody2!=0.0)) {
  qdcmd.extra4="search2="//qdphot.search2//"  odx2="//qdphot.odx2//" ody2="//qdphot.ody2
} else {
  if ((qdphot.dx2!=0.0)||(qdphot.dy2!=0.0)) {
    qdcmd.extra4="dx2="//dx2_//" dy2="//dy2_
  } 
}
qdcmd.xlabel=wfpc2color.oc5txt
qdcmd.ylabel=wfpc2color.oc3txt
qdcmd.title=targname_
qdcmd ( out3_ )

if (print) {
  gflush
  igi (dev="stdplot", < ".qdcmd_igi")
  gflush
  print ( \
    "QDWFPC2: \n", \
    "QDWFPC2: CMD has been sent to stdplot!\n", \
    "QDWFPC2: \n" \
  )
}

bye:

if (qdphot.ostars<50) {
  print ( \
    "QDWFPC2: \n", \
    "QDWFPC2: QDPHOT found only "//qdphot.ostars//" stars.\n", \
    "QDWFPC2: \n", \
    "QDWFPC2: If you expected to find many more stars, try changing the\n", \
    "QDWFPC2: value of the search2 parameter of QDWFPC2 (=", search2, " pixels)\n", \
    "QDWFPC2: and then try executing QDWFPC2 again!\n", \
    "QDWFPC2: \n", \
    "QDWFPC2: Good luck!\n", \
    "QDWFPC2: \n" \
  )
}

end
#









