procedure demostrawman (nx_, ny_, be_, se_,cpxi_, cpyi_, fwhm_, n_)
int nx_=60 {prompt="Number of columns in image?"}
int ny_=60 {prompt="Number of rows in image?"}
real be_=100.0 {prompt="Background (electrons) ?"}
real se_=10000.0 {prompt="Stellar intensity (electrons) ?"}
real cpxi_=30.0 {prompt="X position of the center of 2-d Gaussian (IRAF notation) ?"}
real cpyi_=30.0 {prompt="Y position of the center of 2-d Gaussian (IRAF notation) ?"}
real fwhm_=2.354 {prompt="Full-Width-at-Half-Maximum of 2-d Gaussian ?"}
int n_=10 {prompt="Number of observations to simulate?"}
int mpxi_=1 {prompt="OverSamplingFactor?"}
bool perfect=yes {prompt="Perfect 2-D Gaussian?"}
bool verbose=no {prompt="Verbose?"}
bool show=yes {prompt="Show the simulated observation?"}
string version="2001NOV21" {prompt="DEMOSTRAWMAN version"}
real deltax=1.0 {prompt="Amount of wobble in the X direction (px) ?"}
real deltay=1.0 {prompt="Amount of wobble in the Y direction (px) ?"}

begin

real psf_cpxi
real psf_cpyi
int psf_nx
int psf_ny
real mag
string work
string psf
string psf0
string comment
string out
string lowpass
int nx
int ny
real cpxi
real cpyi
real cpxi0
real cpyi0
real cpxi0m
real cpyi0m
real dx
real dy
real gdx
real gdy
real ddx
real ddy
real fwhm
real hwhm
real be
real se
int i
int j
int n
real ron
real gain
real gse
real gsx
real gsy
real gsf
real gbe
real gbx
real gby
string parflags
real tse
real tsx
real tsy
real tsf
real tbe
real tbx
real tby
bool quiet
int m
string method
real tmag
real gmag
real sx
real sy
real ranx
real rany
real osum
int mpxi
version="2001NOV21"

nx = nx_
ny = ny_
be = be_
se = se_
cpxi0 = cpxi_
cpyi0 = cpyi_
cpxi = cpxi0
cpyi = cpyi0
fwhm = fwhm_
n = n_
mpxi = mpxi_
hwhm = fwhm/2.0
mag = 0
psf = ".demostrawman_psf.imh"
psf0 = ".demostrawman_psf0.imh"
out = ".demostrawman_obs.imh"
lowpass = ".demostrawman_obs_3x3lp.imh"

if (!defpac("stsdas")) {
  print "Please load the STSDAS package!"; 
  goto ciao
}
if (!defpac("artdata")) {
  print "Please load the ARTDATA package!"; 
  goto ciao
}
if (!defpac("ctio")) {
  print "Please load the CTIO package!"; 
  goto ciao
}

cache imgets
cache urand
cache display
cache strawman
cache imdelete
cache psfg2d
cache psfobs
cache imcopy

if (verbose) print  ( "DEMOSTRAWMAN: BEGIN" )

unlearn imcopy
unlearn display
unlearn strawman

for (i=1; i<=n; i+=1) {

if (verbose) print("DEMOSTRAWMAN: ", i)

urand( 1, 2, seed=INDEF) | scan (ranx,rany)
dx = 2.0 * (ranx - 0.5)
dy = 2.0 * (rany - 0.5)
ddx = dx * abs(deltax)
ddy = dy * abs(deltay)
cpxi = cpxi0+ddx
cpyi = cpyi0+ddy
urand( 1, 2, seed=INDEF) | scan (ranx,rany)
gdx = (ranx - 0.5)/3.0
gdy = (rany - 0.5)/3.0
if (verbose) {
  printf("#ranx is %g\n",ranx)
  printf("#rany is %g\n",rany)
  printf("#dx is %g\n",dx)
  printf("#dy is %g\n",dy)
  printf("#ddx is %g\n",ddx)
  printf("#ddy is %g\n",ddy)
  printf("#cpxi is %g\n",cpxi)
  printf("#cpyi is %g\n",cpyi)
  printf("#gdx is %g\n",gdx)
  printf("#gdy is %g\n",gdy)
}

imdelete( psf, go_ahead+, verify-, >& "dev$null" )
imdelete( psf0, go_ahead+, verify-, >& "dev$null" )

#if (perfect) {
  # Create perfect oversampled 2-D Gaussian at (cpxi0m,cpyi0m)
  cpxi0m = cpxi0*mpxi
  cpyi0m = cpyi0*mpxi
  psfg2d (psf0, nx, ny, cpxi0m, cpyi0m, fwhm, verbose=no, mpxi=mpxi)
  minmax( psf0, force=yes, update=yes, >& "dev$null" )
  if (show) display (psf0, 2, zscale=no, zrange=yes, fill=yes, >& "dev$null")
  # Create perfect 2-D Gaussian at final location
  psfg2d (psf, nx, ny, cpxi, cpyi, fwhm, verbose=no, mpxi=1)
  minmax( psf0, force=yes, update=yes, >& "dev$null" )
  if (verbose) printf("Created PSF at (%7.4g,%7.4g)\n",cpxi,cpyi)
  if (show) display (psf, 1, zscale=no, zrange=yes, fill=yes, >& "dev$null")
#} else {
#  # Create perfect 2-D Gaussian at inital location
#  psfg2d (psf0, nx, ny, cpxi0, cpyi0, fwhm, verbose=no, mpxi=mpxi)
#  if (show) display (psf0, 2, zscale=no, zrange=yes, fill=yes, >& "dev$null")
#  if (verbose) printf("Created PSF at (%7.4g,%7.4g)\n",cpxi0,cpyi0)
#  imcopy( psf0, psf,>& "dev$null" )
#  psfshift( psf, ddx, ddy, >& "dev$null")
#  if (verbose) printf("Shifted PSF by (%7.4g,%7.4g)\n",ddx,ddy)
#  if (show) display (psf, 1, zscale=no, zrange=yes, fill=yes, >& "dev$null")
#}

go:

gain = 1.0
#ron = 12.0 # high readout noise level
ron = 3.0 # low readout noise level


imdelete( out, go_ahead+, verify-, >& "dev$null" )
psfobs (psf, out, 
  be, se, bx_=0., by_=0., sxi_=cpxi, syi_=cpyi., gain_=gain,
  ron_=ron, seed_=INDEF, verbose=no)

if (show) display (out, 1, fill=yes, >& "dev$null")

gse = 1.05*se
gsx = cpxi+gdx
gsy = cpyi+gdy
gsf = fwhm
gbe = 0.95*be
gbx = 0.
gby = 0.
parflags = "fccfffc"
tmag = -2.5*log10(se)
gmag = -2.5*log10(gse)
strawman.image = out
strawman.psf = psf0
strawman.gain = gain
strawman.ron = ron
strawman.gse = gse
strawman.gsx = gsx
strawman.gsy = gsy
strawman.gsf = gsf
strawman.gbe = gbe
strawman.gbx = gbx
strawman.gby = gby
strawman.parflags = parflags
strawman.tse = se
strawman.tsx = cpxi
strawman.tsy = cpyi
strawman.tsf = fwhm
strawman.tbe = be
strawman.tbx = 0.
strawman.tby = 0.

for (m=1; m<=2; m+=1) {

if (m==1) {
  method="analytical"
} else {
  method="digital"
}
strawman.method = m

if (verbose) {
strawman ( image=out, psf=psf0,
  gain=gain, ron=ron, gse=gse, gsx=gsx, gsy=gsy, gsf=gsf,
  gbe=gbe, gbx=gbx, gby=gby, parflags=parflags, method=method)
} else {
strawman ( image=out, psf=psf0,
  gain=gain, ron=ron, gse=gse, gsx=gsx, gsy=gsy, gsf=gsf,
  gbe=gbe, gbx=gbx, gby=gby, parflags=parflags, method=method, >& "dev$null")
}

printf("%6d %2d",i,m)
printf("%12.6f%14.8f%12.6f%12.6f",tmag,strawman.osmag,strawman.oesmag,gmag)
printf("%12.6f%12.6f%12.6f%12.6f",strawman.tsx,strawman.osx,strawman.oesx,gsx)
printf("%12.6f%12.6f%12.6f%12.6f",strawman.tsy,strawman.osy,strawman.oesy,gsy)
printf("%12.6e%12.6e%12.6e%12.6e",strawman.tbe,strawman.obe,strawman.oebe,gbe)
printf("%12.6f %9.6f",strawman.orchsq,strawman.oerchsq)
printf("%3d%12.5f",strawman.oniter,strawman.ochisq)
printf("\n")

} # m rof

} # i rof

if (verbose) {
printf("#   (1)(2)   (3)       (4)     (5)       (6)       (7)       (8)")
printf("    (9)       (10)      (11)      (12)   (13)      (14)     (15)")
printf("      (16)    (17)       (18)       (19)   (20)   (21)    (22)\n")
printf("#\n")
printf("#  (1) trial number\n")
printf("#  (2) method (1=analytical, 2=digital)\n")
printf("#  (3) true stellar magnitude\n")
printf("#  (4) measured \"\n")
printf("#  (5) error    \"\n")
printf("#  (6) guess    \"\n")
printf("#  (7) true X position of star\n")
printf("#  (8) measured \"\n")
printf("#  (9) error    \"\n")
printf("# (10) guess    \"\n")
printf("# (11) true Y position of star\n")
printf("# (12) measured \"\n")
printf("# (13) error    \"\n")
printf("# (14) guess    \"\n")
printf("# (15) true background constant \"\n")
printf("# (16) measured \"\n")
printf("# (17) error    \"\n")
printf("# (18) guess    \"\n")
printf("# (19) reduced chi-square\n")
printf("# (20) error    \"\n")
printf("# (21) number of fitting iterations\n")
printf("# (22) chi-square\n")
printf("#\n")
printf("# DEMOSTRAWMAN=%s\n", version)
printf("#\n")
}

ciao:
if (verbose) print  ( "DEMOSTRAWMAN: END" )

end
#
