
/*      FILE: par_get.c
 *   PURPOSE: Get wfpc2color2_ParS input parameters
 *    AUTHOR: Kenneth J. Mighell (mighell@noao.edu)
 *  LANGUAGE: ANSI C
 *      DATE: 2001JUN06
 * COPYRIGHT: (C) 2001 Assoc. of Universities for Research in Astronomy Inc.
 */

#include "mx.h"
#include "wfpc2color.h"

int wfpc2color2_ParS_Get_i1 (
  wfpc2color2_ParS *ParS
){
  char mxfunc[] = "wfpc2color2_ParS_Get_i1";
  int status = 0;
  int is_INDEF;
  double d;
  int i, j;
  int valuei;
  double valued;
  double defaultd;
  int expressioni;
  char smag1[2];
  char smag2[2];
  char scol[16];
  char scol_default[16];
  double t1;
  double t2;
  double z;
  int flipper;

  char *p_expsec[] = { "", "expsec1", "expsec2" };
  char *p_imag[] = { "", "imag1", "imag2" }; 
  char *p_mxerr[] = { "", "mxerr1", "mxerr2" }; 
  char *p_ycte[] = { "", "ycte1", "ycte2" }; 
  char *p_xcte[] = { "", "xcte1", "xcte2" }; 
  char *p_delta[] = { "", "delta1", "delta2" }; 
  char *p_apcor[] = { "", "apcor1", "apcor2" }; 
  char *p_asmag[] = { "", "asmag1", "asmag2" }; 
  char *p_aimag[] = { "", "aimag1", "aimag2" }; 
  char *p_zsyn[] = { "", "zsyn1", "zsyn2" }; 
  char *p_cmax[] = { "", "cmax1", "cmax2" }; 
  char *p_cmin[] = { "", "cmin1", "cmin2" }; 
  char *p_z[] = { "", "z1", "z2" }; 
  char *p_t2[] = { "", "t21", "t22" }; 
  char *p_t1[] = { "", "t11", "t12" }; 
  char *p_gain[] = { "", "gain1", "gain2" };
  char *p_smag[] = { "", "smag1", "smag2" }; 
  char *p_ccdnum[] = { "", "ccdnum1", "ccdnum2" }; 
  char *p_atodgn[] = { "", "atodgn1", "atodgn2" }; 

  j = 1;
  c_clgstr ("in1", ParS->in1, sizeof(ParS->in1));
  if (mxiraf_cvos_error_check_f0()) {status=2; goto mx_error1;}
  strcpy( ParS->in[j], ParS->in1);

  j = 2;
  c_clgstr ("in2", ParS->in2, sizeof(ParS->in2));
  if (mxiraf_cvos_error_check_f0()) {status=2; goto mx_error1;}
  strcpy( ParS->in[j], ParS->in2);

  j = 1;
  ParS->image_is_INDEF[j] = MX_FALSE;
  c_clgstr ("image1", ParS->image1, sizeof(ParS->image1));
  if (mxiraf_cvos_error_check_f0()) {status=2; goto mx_error1;}
  strcpy( ParS->image[j], ParS->image1);
  if (ParS->image[j][0] == '\0') ParS->image_is_INDEF[j] = MX_TRUE;
  status = wfpc2color2_KeyS_Get_i2( ParS, j );
  if (status) {status=2; goto mx_error1;}

  j = 2;
  ParS->image_is_INDEF[j] = MX_FALSE;
  ParS->image2_is_image1 = MX_FALSE;
  c_clgstr ("image2", ParS->image2, sizeof(ParS->image2));
  if (mxiraf_cvos_error_check_f0()) {status=2; goto mx_error1;}
  strcpy( ParS->image[j], ParS->image2);
  if (ParS->image[j][0] == '\0') {
    strcpy( ParS->image[1], ParS->image[1]);
    ParS->image_is_INDEF[2] = MX_TRUE;
    ParS->image2_is_image1 = MX_TRUE;
  }
  status = wfpc2color2_KeyS_Get_i2( ParS, j );
  if (status) {status=2; goto mx_error1;}

  for ( j=1; j<=2; ++j ) {

    if (j==1) {
      status = wfpc2color2_IrafParStringGet_v5( 
        "field", "", ParS->field, sizeof(ParS->field), &ParS->field_is_INDEF );
      if (status) {status=5; goto mx_error1;}
    }

    ParS->ccdnum[0] = 1;
    if (!ParS->image_is_INDEF[j]) 
      ParS->ccdnum[0] = ParS->KeyS[j].detector;
    if (j==2) ParS->ccdnum[0] = ParS->ccdnum[1];
    status = wfpc2color2_IrafParIntegerGet_v4( p_ccdnum[j], ParS->ccdnum[0],
      &ParS->ccdnum[j], &ParS->ccdnum_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}
    if ( (ParS->ccdnum[j]<1) || (ParS->ccdnum[j]>4) ) {
      sprintf( MX.tmpmsg, "bad ccdnum%d value: %d\n", j, i);
      goto mx_error2;
    }

    defaultd = 15.0;
    if (!ParS->image_is_INDEF[j]) 
      defaultd = ParS->KeyS[j].atodgain;
    status = wfpc2color2_IrafParDoubleGet_v4( p_atodgn[j], defaultd,
      &valued, &ParS->atodgn_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}
    expressioni = valued + 0.5;
    switch (expressioni) {
      case  7 : { valuei = WFPC2_GAIN_LOW;  valued = 7; break;}
      case 15 : { valuei = WFPC2_GAIN_HIGH; valued = 15; break;}
      default : {
        sprintf( MX.tmpmsg, "bad ATODGN%d value: %g\n", j, valued);
        goto mx_error2;
      }
    }
    ParS->atodgn[j] = valued;
    ParS->wfpc2_gain[j] = valuei;

    ParS->expsec[0] = 1.0;
    if (!ParS->image_is_INDEF[j]) 
      ParS->expsec[0] = ParS->KeyS[j].exptime;
    status = wfpc2color2_IrafParDoubleGet_v4( p_expsec[j], ParS->expsec[0],
      &ParS->expsec[j], &ParS->expsec_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}

    strcpy( ParS->imag[0], "" );
    if (!ParS->image_is_INDEF[j]) 
      strcpy( ParS->imag[0], ParS->KeyS[j].filtnam1 );
    status = wfpc2color2_IrafParStringGet_v5( p_imag[j], ParS->imag[0], 
      ParS->imag[j], sizeof(ParS->imag[j]), &ParS->imag_is_INDEF[j] );
    if (status) {status=5; goto mx_error1;}

    ParS->mxerr[0] = 0.2;
    status = wfpc2color2_IrafParDoubleGet_v4( p_mxerr[j], ParS->mxerr[0],
      &ParS->mxerr[j], &ParS->mxerr_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}

    ParS->ycte[0] = 0.04;
    status = wfpc2color2_IrafParDoubleGet_v4( p_ycte[j], ParS->ycte[0],
      &ParS->ycte[j], &ParS->ycte_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}

    ParS->xcte[0] = 0.0;
    status = wfpc2color2_IrafParDoubleGet_v4( p_xcte[j], ParS->xcte[0],
      &ParS->xcte[j], &ParS->xcte_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}

    ParS->delta[0] = 0.0;
    status = wfpc2color2_IrafParDoubleGet_v4( p_delta[j], ParS->delta[0],
      &ParS->delta[j], &ParS->delta_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}

    ParS->apcor[0] = 0.0;
    if (j==2) ParS->apcor[0] = ParS->apcor[1];
    status = wfpc2color2_IrafParDoubleGet_v4( p_apcor[j], ParS->apcor[0],
      &ParS->apcor[j], &ParS->apcor_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}

    ParS->asmag[0] = 0.0;
    status = wfpc2color2_IrafParDoubleGet_v4( p_asmag[j], ParS->asmag[0],
      &ParS->asmag[j], &ParS->asmag_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}

    ParS->aimag[0] = 0.0;
    status = wfpc2color2_IrafParDoubleGet_v4( p_aimag[j], ParS->aimag[0],
      &ParS->aimag[j], &ParS->aimag_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}

    ParS->zsyn[0] = 0.0;
    status = wfpc2color2_IrafParDoubleGet_v4( p_zsyn[j], ParS->zsyn[0],
      &ParS->zsyn[j], &ParS->zsyn_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}

    ParS->cmax[0] = 99.999;
    status = wfpc2color2_IrafParDoubleGet_v4( p_cmax[j], ParS->cmax[0],
      &ParS->cmax[j], &ParS->cmax_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}

    ParS->cmin[0] = -99.999;
    status = wfpc2color2_IrafParDoubleGet_v4( p_cmin[j], ParS->cmin[0],
      &ParS->cmin[j], &ParS->cmin_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}

    ParS->z[0] = 0.0;
    status = wfpc2color2_IrafParDoubleGet_v4( p_z[j], ParS->z[0],
      &ParS->z[j], &ParS->z_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}

    ParS->t2[0] = 0.0;
    status = wfpc2color2_IrafParDoubleGet_v4( p_t2[j], ParS->t2[0],
      &ParS->t2[j], &ParS->t2_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}

    ParS->t1[0] = 0.0;
    status = wfpc2color2_IrafParDoubleGet_v4( p_t1[j], ParS->t1[0],
      &ParS->t1[j], &ParS->t1_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}

    ParS->gain[0] = 1.0;
    if (j==2) ParS->gain[0] = ParS->gain[1];
    status = wfpc2color2_IrafParDoubleGet_v4( p_gain[j], ParS->gain[0],
      &ParS->gain[j], &ParS->gain_is_INDEF[j]);
    if (status) {status=5; goto mx_error1;}

    strcpy( ParS->smag[0], "?" );
    status = wfpc2color2_IrafParStringGet_v5( p_smag[j], ParS->smag[0], 
      ParS->smag[j], sizeof(ParS->smag[j]), &ParS->smag_is_INDEF[j] );
    if (status) {status=5; goto mx_error1;}

  } /* loop over j */

  wfpc2color2_Check_Transform_i1( ParS );

  /*
   * ========================================================================
   */

  /* 
   * Read instrumental magnitudes for the 1st filter 
   */
  status = wfpc2color2_ParS_ImagS_File_i2 (ParS, 1);
  if (status) {status=1; goto mx_error2;}

  /* 
   * Read instrumental magnitudes for the 2nd filter 
   */
  status = wfpc2color2_ParS_ImagS_File_i2 (ParS, 2);
  if (status) {status=1; goto mx_error2;}

ok:
  status = 0;
  goto bye;

mx_error1:
  mxp_tmpmsg_init_f0();
mx_error2:
  mxp_errmsg_append_f3 (mxfunc, status, MX.tmpmsg);
  mxp_tmpmsg_init_f0();
  status = 1;
  goto bye;

bye:
  return(status);

}
/* end-of-file */









