
/*      FILE: par_imag_file.c
 *   PURPOSE: (1) Open the instrumental magnitude file
 *            (2) Create and fill the wfpc2color2_ParS->wfpc2color2_ImagS
 *            (3) Close the instrumental magnitude file
 *    AUTHOR: Kenneth J. Mighell (mighell@noao.edu)
 *  LANGUAGE: ANSI C
 *      DATE: 2001MAY22
 * COPYRIGHT: (C) Assoc. of Universities for Research in Astronomy Inc.
 */

#include "mx.h"
#include "wfpc2color.h"

#define DEBUG (MX_FALSE)

int wfpc2color2_ParS_ImagS_File_i2 (
  wfpc2color2_ParS *ParS,
  int index
){

  char mxfunc[] = "wfpc2color2_ParS_ImagS_File_i1";
  int mxstatus = 0;

#define CARDSIZE (1024)
  char card[CARDSIZE];
  double imagxd;
  double imagyd;
  int imagidi;
  int j;
  int k;
  int items;
  double cxd;
  double cyd;
  int cidi;
  double cmagd;
  double cerrd;
  FILE *ifp;
  int nlines;

  j = index;

  /*
   * Abort if there is no instrumental magnitude file
   */
  if ( (ParS->in[index]) == '\0' ) goto bye;

  if (DEBUG) printf( 
    "# Try to open instrumental magnitude file\n\"%s\"\n", 
    ParS->in[index]
  );

  ifp = fopen( ParS->in[index], "r");
  if ( (FILE *)NULL == ifp ) {
    mxstatus = 2;
    sprintf (
      MX.tmpmsg,
      "#   Could not open instrumental magnitude file\n"
      "#     \"%s\"\n",
      ParS->in[index]
    );
    goto mx_error2;
  }

  k = 0;
  while ( (char *)NULL != fgets(card, CARDSIZE, ifp) ) k++;
  ParS->idim[index] = k;
  if (DEBUG) 
    printf( "# %d lines total\n", ParS->idim[index]);
  rewind(ifp);

  /* Allocate ParS->ImagS */
  ParS->ImagS[index] = 
    (wfpc2color2_ImagS *)malloc(sizeof(wfpc2color2_ImagS)*ParS->idim[index]);

  j = -1;
  for ( k=0; k<ParS->idim[index]; k++ ) {
    fgets(card, CARDSIZE, ifp);
    items = sscanf( 
      card, 
      "%lf%lf%d%lf%lf", 
      &cxd,
      &cyd, 
      &cidi, 
      &cmagd, 
      &cerrd
    );
    if (items == 5) {
      j++;
      if (j == ParS->idim[index]) {
	mxstatus = 4;
	sprintf (
	  MX.tmpmsg,
	  "#   Yikes!  j == idim (array bounds exceeded!)\n"
	);
	goto mx_error2;
      }
      ParS->ImagS[index][j].xd = cxd;
      ParS->ImagS[index][j].yd = cyd;
      ParS->ImagS[index][j].idi = cidi;
      ParS->ImagS[index][j].magd = cmagd;
      ParS->ImagS[index][j].errd = cerrd;
      if (DEBUG) printf( "%g %g %d %g %g *\n",
	ParS->ImagS[index][j].xd,
        ParS->ImagS[index][j].yd,
	ParS->ImagS[index][j].idi,
        ParS->ImagS[index][j].magd,
        ParS->ImagS[index][j].errd
      );
    } else {
	if (DEBUG) printf( 
          "# *** WARNING *** Could not read line %d : %s", (k+1), card );
    }
  }
  ParS->instars[index] = j+1;
  if (DEBUG) printf( "# %d stars total\n", ParS->instars[index] );

  /* Close instrumental coordinate file */  
  fclose( ifp );

ok:
  mxstatus = 0;
  goto bye;

mx_error1:
  mxp_tmpmsg_init_f0();
mx_error2:
  mxp_errmsg_append_f3 (mxfunc, mxstatus, MX.tmpmsg);
  mxp_tmpmsg_init_f0();
  goto bye;

bye:
  return(mxstatus);

#undef CARDSIZE
#undef DEBUG
}
/* end-of-file */
